package addressbook;

/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DeleteContact.java 581305 2007-10-02 16:55:49Z vgritsenko $
 */
 
import java.io.IOException;
import java.net.URLEncoder;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

import org.xmldb.api.base.Collection;

// Class for deleting records from the database
public class DeleteContact extends Action {

   // Delete the document with a key value of request.index
   public boolean delete(HttpServletRequest request, HttpServletResponse response ) throws ServletException, IOException {
   
      Collection col;
      try {
         // Get a reference to the session
         HttpSession session = request.getSession(true);
   
         // Get a collection instance
         col = getCollection(request,response);
                  
         // Get the index we are going to delete
         int index = Integer.parseInt(request.getParameter("index"));
         
         // Pull the Group out of the session, and get the Person instance at the Index
         Group group = (Group)session.getAttribute("group");
         Person person = group.getPersonAt(index);
         
         // Get the documentKey for this particular Person
         String dockey = person.getDocKey();
         
         // Delete the document
         col.removeResource(col.getResource(dockey) );
         
      } catch (Exception e) {
          e.printStackTrace();

          // there's not much else we can do if the response is committed
          if (response.isCommitted()) {
              return true;
          }

         // Catch the exception and send the user to the error page
         if (e.getMessage() != null ) {
            response.sendRedirect("/addressbook/error.jsp?error=" + URLEncoder.encode(e.getMessage(), "UTF-8"));
         } else {
            response.sendRedirect("/addressbook/error.jsp");
         }
      }

      return true;
   }
}

