/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: MetaService.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.client.xmldb.services;

import org.apache.xindice.client.xmldb.CommonConfigurable;
import org.apache.xindice.client.xmldb.XindiceCollection;
import org.apache.xindice.core.meta.MetaData;

import org.xmldb.api.base.Collection;
import org.xmldb.api.base.Service;
import org.xmldb.api.base.XMLDBException;

/**
 * Meta information service.
 *
 * @author <a href="mailto:vgritsenko@apache.org">Vadim Gritsenko</a>
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class MetaService extends CommonConfigurable implements Service {

    /**
     * Collection that this query service should query in
     */
    private Collection collection;

    public String getVersion() {
        return "1.0";
    }

    public String getName() {
        return "MetaService";
    }

    public void setCollection(Collection collection) {
        this.collection = collection;
    }

    public MetaData getMetaData() throws XMLDBException {
        return ((XindiceCollection) collection).getMetaData(null);
    }

    public void setMetaData(MetaData meta) throws XMLDBException {
        ((XindiceCollection) collection).setMetaData(null, meta);
    }

    public MetaData getMetaData(String id) throws XMLDBException {
        return ((XindiceCollection) collection).getMetaData(id);
    }

    public void setMetaData(String id, MetaData meta) throws XMLDBException {
        ((XindiceCollection) collection).setMetaData(id, meta);
    }

    public long getLastModifiedTime() throws XMLDBException {
        return ((XindiceCollection) collection).getMetaData(null).getLastModifiedTime();
    }

    public long getCreatedTime() throws XMLDBException {
        return ((XindiceCollection) collection).getMetaData(null).getCreatedTime();
    }

    public long getLastModifiedTime(String name) throws XMLDBException {
        return ((XindiceCollection) collection).getMetaData(name).getLastModifiedTime();
    }

    public long getCreatedTime(String name) throws XMLDBException {
        return ((XindiceCollection) collection).getMetaData(name).getCreatedTime();
    }
}
