/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Streamable.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.core.filer;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

/**
 * Streamable is an interface implemented by objects used by Filers and
 * Indexers in order to serialize objects to and from IO streams.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface Streamable {

    /**
     * read reads the object state from the stream.
     *
     * @param is The DataInputStream
     * @throws IOException if an IOException occurs
     */
    public void read(DataInput is) throws IOException;

    /**
     * write writes the object state to the stream.
     *
     * @param os The DataOutputStream
     * @throws IOException if an IOException occurs
     */
    public void write(DataOutput os) throws IOException;
}
