/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: InlineMetaReader.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.core.meta.inline;

import org.apache.xindice.core.data.Value;

/**
 * The <code>Value</code> associated with a <code>Record</code>
 * can be prefixed by a header containing 'inline' metadata.
 * The original motivation for
 * this extension is to support binary resources in the same
 * filer where the XML documents live.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface InlineMetaReader {

    /**
     * The second byte of the header contains the version.
     * The reader which is called to read the header is
     * determined by the version.
     */
    int getVersion();

    /**
     * When a header is read, it generates a <code>Map</code>
     * containing the attributes carried by the header.
     *
     * @param data Value object in which the header is embedded
     * @return Map containing the attributes read from the header
     * @throws InlineMetaException if the header data is corrupted or of
     *         the wrong length
     */
    InlineMetaMap read(Value data) throws InlineMetaException;
}
