/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: XindiceStreamHandlerFactory.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.core.request;

import java.net.URL;
import java.net.URLStreamHandler;
import java.net.URLStreamHandlerFactory;

/**
 * This interface defines a factory for URL stream protocol handlers.
 * It is used by the URL class to create a URLStreamHandler for a specific protocol.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class XindiceStreamHandlerFactory implements URLStreamHandlerFactory {

    static {
        URL.setURLStreamHandlerFactory(new XindiceStreamHandlerFactory());
    }

    private static final String PROTOCOL = "xindice";

    /**
     * Creates an instance of an URLStreamHandler
     */
    public URLStreamHandler createURLStreamHandler(String protocol) {

        // If dealing with a Xindice object, return our stream handler
        if (protocol.equalsIgnoreCase(PROTOCOL)) {
            return new XindiceStreamHandler();
        }
        // Else return null to use default stream handler for protocol
        else {
            return null;
        }
    }
}
