/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DeleteDocument.java 578602 2007-09-23 20:33:31Z natalia $
 */

package org.apache.xindice.tools.command;

import org.apache.xindice.tools.XMLTools;

import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;
import org.xmldb.api.base.Resource;

/**
 * DeleteDocument.java is designed to let the user delete or drop
 * a Document, referred by the Key, from a specific Collection or Nested
 * Collection.
 *
 * @version $Revision: 578602 $, $Date: 2007-09-23 16:33:31 -0400 (Sun, 23 Sep 2007) $
 */
public class DeleteDocument extends Command {

    public boolean execute(XMLTools.Config table) throws Exception {
        if (table.getString(XMLTools.COLLECTION) == null) {
            System.out.println("ERROR : Collection and switch required");
            return false;
        }

        if (table.getString(XMLTools.NAME_OF) == null) {
            System.out.println("ERROR : Document Key and switch required");
            return false;
        }

        Collection col = null;
        try {
            // Get a Collection reference to the collection to be deleted
            String colstring = normalizeCollectionURI(table.getString(XMLTools.COLLECTION),
                                                      table.getBoolean(XMLTools.LOCAL));

            col = DatabaseManager.getCollection(colstring);
            if (col == null) {
                System.out.println("ERROR : Collection not found!");
                return false;
            }

            Resource colresource = col.getResource(table.getString(XMLTools.NAME_OF));

            col.removeResource(colresource);
            System.out.println("DELETED: " + table.getString(XMLTools.COLLECTION) + "/" + table.getString(XMLTools.NAME_OF));
        } finally {
            if (col != null) {
                col.close();
            }
        }

        return true;
    }

    public void usage() {
        System.out.println("Format: xindice dd -c <context> [-l [-d <path>]] [-v] [parameters...]");
        System.out.println();
        System.out.println("Deletes a document/binary resource, referred by the key, from a specific");
        System.out.println("collection");
        System.out.println();
        System.out.println("Command-specific switches:");
        System.out.println("    -n|--nameOf <name>");
        System.out.println("                 Key of the resource to be deleted");
        System.out.println();
        System.out.println("Examples:");
        System.out.println("    xindice dd -c /db/test -n myxmldocument");
        System.out.println();
    }
}
