/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Poolable.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.util;

/**
 * Poolable is an interface that must be implemented by Objects that are
 * capable of being managed in a pooled fashion by Xindice.
 *
 * @see org.apache.xindice.util.ObjectPool
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface Poolable {

    /**
     * setPool passes a reference to the originating ObjectPool for this
     * Object.  This will allow the Poolable Object to call back to the
     * ObjectPool in order to be reclaimed.
     *
     * @param pool The parent ObjectPool
     */
    void setPool(ObjectPool pool);

    /**
     * reclaim prompts the Poolable object to return itself to the
     * ObjectPool.  A Poolable implementation should perform any
     * necessary cleanup before calling pool.putObject to return
     * itself to the ObjectPool.
     */
    void reclaim();
}
