/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.xindice.webadmin.webdav.components.props;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.data.Entry;
import org.apache.xindice.webadmin.PartialResponse;
import org.apache.xindice.webadmin.util.MimeTable;

/**
 * ContentType creates a response node that identifies content type of
 * the collection entry. It is not applicable for collections and always
 * contains "text/xml" for documents. For binary entries ContentType
 * attemps to guess content type, if unsuccessful, it will assume default
 * binary type of "application/octet-stream".
 * <br/><br/>
 * Example:
 * <pre>
 * &lt;getcontenttype&gt;
 *     text/xml
 * &lt;/getcontenttype&gt;
 * </pre>
 *
 * @version $Revision: 541515 $, $Date: 2007-05-24 22:45:06 -0400 (Thu, 24 May 2007) $
 */
public class ContentType implements DAVProperty {
    private static final String CONTENT_TYPE = "getcontenttype";

    public String getName() {
        return CONTENT_TYPE;
    }

    public PartialResponse.Content getRootProperty() {
        return null;
    }

    public PartialResponse.Content getProperty(Collection col) {
        return null;
    }

    public PartialResponse.Content getProperty(Entry entry) {
        if (entry.getEntryType() == Entry.DOCUMENT) {
            return new PartialResponse.Content(CONTENT_TYPE, MimeTable.XML_MIME_TYPE);
        } else {
            return new PartialResponse.Content(CONTENT_TYPE, MimeTable.getMimeType(entry.getKey().toString()));
        }
    }

}
