/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: XMLSerializable.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.xml;

import org.w3c.dom.DOMException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * XMLSerializable is the interface that must be implemented by XMLSerializable
 * classes.  XMLSerializable classes are those classes whose state can be
 * retrieved and stored as XML.
 *
 * @see org.apache.xindice.xml.SymbolTable
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface XMLSerializable {

    /**
     * streamToXML streams a Java object to the DOM node.
     *
     * Passed owner document is used to create nodes and should not
     * be modified.
     *
     * @param doc The Owner Document
     * @return A newly created Element
     * @throws DOMException If an error occurs
     */
    Element streamToXML(Document doc) throws DOMException;

    /**
     * streamFromXML streams an object from the DOM node.
     *
     * @param element The Input Element
     * @throws DOMException If an error occurs
     */
    void streamFromXML(Element element) throws DOMException;
}
