/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DBNode.java 571948 2007-09-02 10:51:37Z vgritsenko $
 */

package org.apache.xindice.xml.dom;

import org.apache.xindice.xml.NodeSource;

import org.w3c.dom.DOMException;
import org.w3c.dom.Node;

/**
 * DBNode represents a Xindice Collection-originating Node.  DBNodes will
 * provide Node sourcing and Transaction capabilities for Nodes that have
 * been aggregated into external Documents.
 *
 * @version $Revision: 571948 $, $Date: 2007-09-02 06:51:37 -0400 (Sun, 02 Sep 2007) $
 */
public interface DBNode extends Node {

    /**
     * getSource returns a source for this Node.
     *
     * @return The Document source
     */
    NodeSource getSource();

    /**
     * setSource sets a source for this Node.
     *
     * @param source The Document source
     * @throws DOMException if an exception occurs
     */
    void setSource(NodeSource source) throws DOMException;

    /**
     * expandSource expands the source into the Node as
     * a namespace and a set of attributes.  This method
     * will only work on a Document or an Element, and
     * should silently fail on all other Node types.
     */
    void expandSource();
}
