/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: ConfigurationTest.java 564825 2007-08-11 02:49:10Z natalia $
 */

package org.apache.xindice.util;

import org.apache.xindice.server.Xindice;
import org.apache.xindice.xml.dom.DOMParser;

import junit.framework.TestCase;
import org.w3c.dom.Document;

/**
 * @version $Revision: 564825 $, $Date: 2007-08-10 22:49:10 -0400 (Fri, 10 Aug 2007) $
 * @author Vladimir R. Bossicard <vladimir@apache.org>
 */
public class ConfigurationTest extends TestCase {

    Document document;

    protected void setUp() throws Exception {
        document = DOMParser.toDocument(Xindice.DEFAULT_CONFIGURATION);
    }

    /**
     * Test getName, getChild, getAttribute, etc
     */
    public void testGet() throws Exception {
        Configuration config = new Configuration(document);
        assertEquals("xindice", config.getName());

        config = config.getChild("root-collection", false);
        assertEquals("root-collection", config.getName());
        assertEquals("./db/", config.getAttribute("dbroot"));
        assertEquals("db", config.getAttribute("name"));

        assertEquals("", config.getAttribute("does-not-exist"));
        assertEquals("some-default-value", config.getAttribute("does-not-exist", "some-default-value"));
        assertEquals(false, config.getBooleanAttribute("does-not-exist"));
        assertEquals(true, config.getBooleanAttribute("does-not-exist", true));

        config = config.getChild("queryengine", false);
        assertEquals("queryengine", config.getName());

        Configuration[] children = config.getChildren();
        assertEquals(3, children.length);
        assertEquals("resolver", children[0].getName());
        assertEquals("resolver", children[1].getName());
        assertEquals("resolver", children[2].getName());
    }

    public void testEditReadonly() throws Exception {
        Configuration config = new Configuration(document);
        try {
            config.getChild("does-not-exist", true);
            fail("ReadOnlyException expected");
        } catch (ReadOnlyException e) {
            // Expected
        }
        assertFalse(config.isDirty());

        try {
            config.add("does-not-exist");
            fail("ReadOnlyException expected");
        } catch (ReadOnlyException e) {
            // Expected
        }
        assertFalse(config.isDirty());

        try {
            config.setAttribute("does-not-exist", 7);
            fail("ReadOnlyException expected");
        } catch (ReadOnlyException e) {
            // Expected
        }
        assertFalse(config.isDirty());
    }

    public void testEdit() throws Exception {
        Configuration config = new Configuration(document, false);

        Configuration child = config.getChild("does-not-exist", true);
        assertEquals("does-not-exist", child.getName());
        assertEquals("does-not-exist", config.getChild("does-not-exist").getName());
        assertTrue(config.isDirty());

        child.setAttribute("does-not-exist", 7);
        assertEquals(7, child.getIntAttribute("does-not-exist"));
        assertTrue(child.isDirty());
    }
}
